@@ -9,9 +9,17 @@ import shutil
 
 
 class CentralReachCore(SitesCore):
-    def __init__(self, login: str, password: str, url: str = 'https://members.centralreach.com/#login',
-                 start_date: date = date.today().replace(day=1), end_date: date = date.today(),
-                 timeout: int = 30, temp_folder: str = '', headless: bool = False):
+    def __init__(
+        self,
+        login: str,
+        password: str,
+        url: str = "https://members.centralreach.com/#login",
+        start_date: date = date.today().replace(day=1),
+        end_date: date = date.today(),
+        timeout: int = 30,
+        temp_folder: str = "",
+        headless: bool = False,
+    ):
         """
         CentralReachCore object. Please Inheritance it.
 
@@ -57,11 +65,17 @@ class CentralReachCore(SitesCore):
                 self.browser.input_text_when_element_is_visible('//input[@type="password"]', self.password)
                 self.browser.click_button_when_visible('//button[@id="login"]')
 
-                if self.browser.does_page_contain_element('//div[@class="loginError"]/div[text()="There was an unexpected problem signing in. If you keep seeing this, please contact CentralReach Support"]'):
-                    elem = self.browser.find_element('//div[@class="loginError"]/div[text()="There was an unexpected problem signing in. If you keep seeing this, please contact CentralReach Support"]')
+                if self.browser.does_page_contain_element(
+                    '//div[@class="loginError"]/div[text()="There was an unexpected problem signing in. If you keep seeing this, please contact CentralReach Support"]'  # noqa
+                ):
+                    elem = self.browser.find_element(
+                        '//div[@class="loginError"]/div[text()="There was an unexpected problem signing in. If you keep seeing this, please contact CentralReach Support"]'  # noqa
+                    )
                     if elem.is_displayed():
-                        logging.warning('Logging into CentralReach failed. There was an unexpected problem signing in.')
-                        raise CentralReachException('There was an unexpected problem signing in. If you keep seeing this, please contact CentralReach Support')
+                        logging.warning("Logging into CentralReach failed. There was an unexpected problem signing in.")
+                        raise CentralReachException(
+                            "Unexpected error during signing in. If you keep seeing this, contact CentralReach Support"
+                        )
 
                 self.wait_element_and_refresh('//span[text()="Favorites"]', is_need_screenshot=False)
                 self.is_site_available = self.browser.does_page_contain_element('//span[text()="Favorites"]')
@@ -70,11 +84,9 @@ class CentralReachCore(SitesCore):
             except ScheduledMaintenance as ex:
                 raise ex
             except Exception as ex:
-                logging.error(f'Logging into CentralReach. Attempt #{i} failed')
+                logging.error(f"Logging into CentralReach. Attempt #{i} failed")
                 logging.error(str(ex))
-                self.browser.capture_page_screenshot(
-                    os.path.join(self.output_folder, f'Login_failed_Attempt_{i}.png')
-                )
+                self.browser.capture_page_screenshot(os.path.join(self.output_folder, f"Login_failed_Attempt_{i}.png"))
                 self.browser.close_browser()
         return False
 
@@ -105,8 +117,12 @@ class CentralReachCore(SitesCore):
                     time.sleep(1)
 
             if not is_success:
-                if self.browser.does_page_contain_element("//div[@id='select2-drop']/ul[@class='select2-results']/li[@class='select2-no-results']"):
-                    elem = self.browser.find_element("//div[@id='select2-drop']/ul[@class='select2-results']/li[@class='select2-no-results']")
+                if self.browser.does_page_contain_element(
+                    "//div[@id='select2-drop']/ul[@class='select2-results']/li[@class='select2-no-results']"
+                ):
+                    elem = self.browser.find_element(
+                        "//div[@id='select2-drop']/ul[@class='select2-results']/li[@class='select2-no-results']"
+                    )
                     if elem.is_displayed():
                         break
         if not is_success and is_need_screenshot:
@@ -123,12 +139,14 @@ class CentralReachCore(SitesCore):
             for element in elements:
                 try:
                     if element.is_displayed():
-                        logging.warning('A pop-up appeared and the bot closed it. Please validate the screenshot of the pop-up in the artifacts.')
+                        logging.warning(
+                            "A pop-up appeared and the bot closed it. Please validate the screenshot in the artifacts."
+                        )
                         self.browser.capture_page_screenshot(
                             os.path.join(self.output_folder, f'Pop_up_{datetime.now().strftime("%H_%M_%S")}.png')
                         )
                         element.click()
-                        self.browser.wait_until_element_is_not_visible(f'({xpath})[{elements.index(element) + 1}]')
+                        self.browser.wait_until_element_is_not_visible(f"({xpath})[{elements.index(element) + 1}]")
                 except (AssertionError, SeleniumLibrary.errors.ElementNotFound):
                     time.sleep(1)
 
@@ -138,8 +156,10 @@ class CentralReachCore(SitesCore):
                 self.browser.capture_page_screenshot(
                     os.path.join(self.output_folder, f'Maintenance_{datetime.now().strftime("%H_%M_%S")}.png')
                 )
-                raise ScheduledMaintenance('Data processing stopped due to Scheduled Maintenance. '
-                                           'Please run the bot again when the CentralReach is available')
+                raise ScheduledMaintenance(
+                    "Data processing stopped due to Scheduled Maintenance. "
+                    "Please run the bot again when the CentralReach is available"
+                )
 
     def wait_element_and_refresh(self, xpath: str, timeout: int = 120, is_need_screenshot: bool = True) -> bool:
         """
@@ -165,7 +185,7 @@ class CentralReachCore(SitesCore):
             )
         return is_success
 
-    def apply_filter(self, filter_name: str, additional_params: str = '', is_need_wait: bool = True):
+    def apply_filter(self, filter_name: str, additional_params: str = "", is_need_wait: bool = True):
         if self.browser.does_page_contain_element('//li/a[@data-click="openMenu"]'):
             if self.browser.find_element('//li/a[@data-click="openMenu"]').is_displayed():
                 self.click('//li/a[@data-click="openMenu"]')
@@ -191,14 +211,18 @@ class CentralReachCore(SitesCore):
 
         if is_need_wait:
             self.browser.wait_until_element_is_not_visible("//em[contains(., '<loading>')]", timedelta(seconds=45))
-            self.browser.wait_until_element_is_not_visible("//div[contains(@data-bind, 'loading()')]", timedelta(seconds=45))
+            self.browser.wait_until_element_is_not_visible(
+                "//div[contains(@data-bind, 'loading()')]", timedelta(seconds=45)
+            )
 
     def is_no_results(self) -> bool:
-        if self.browser.does_page_contain_element('//div[text()="No results matched your keywords, filters, or date range" and not(@style="display: none;")]'):
+        if self.browser.does_page_contain_element(
+            '//div[text()="No results matched your keywords, filters, or date range" and not(@style="display: none;")]'
+        ):
             return True
         return False
 
-    def apply_label(self, label_add: str, label_remove: str = '') -> None:
+    def apply_label(self, label_add: str, label_remove: str = "") -> None:
         self.wait_element('//button[contains(., "Label selected")]')
         self.browser.click_element_when_visible('//button[contains(., "Label selected")]')
 
@@ -206,7 +230,9 @@ class CentralReachCore(SitesCore):
             self.wait_element('//h4[text()="Apply Labels"]/../../div/div/ul/li/input')
             self.browser.input_text('//h4[text()="Apply Labels"]/../../div/div/ul/li/input', label_add)
             self.wait_element(f'//div[text()="{label_add}" and @role="option"]')
-            if self.browser.does_page_contain_element("//div[@id='select2-drop']/ul[@class='select2-results']/li[@class='select2-no-results']"):
+            if self.browser.does_page_contain_element(
+                "//div[@id='select2-drop']/ul[@class='select2-results']/li[@class='select2-no-results']"
+            ):
                 self.browser.input_text('//h4[text()="Apply Labels"]/../../div/div/ul/li/input', label_add.lower())
                 self.wait_element(f'//div[text()="{label_add}" and @role="option"]')
             self.browser.click_element_when_visible(f'//div[text()="{label_add}" and @role="option"]')
@@ -214,7 +240,9 @@ class CentralReachCore(SitesCore):
             self.wait_element('//h4[text()="Remove Labels"]/../../div/div/ul/li/input')
             self.browser.input_text('//h4[text()="Remove Labels"]/../../div/div/ul/li/input', label_remove)
             self.wait_element(f'//div[text()="{label_remove}" and @role="option"]')
-            if self.browser.does_page_contain_element("//div[@id='select2-drop']/ul[@class='select2-results']/li[@class='select2-no-results']"):
+            if self.browser.does_page_contain_element(
+                "//div[@id='select2-drop']/ul[@class='select2-results']/li[@class='select2-no-results']"
+            ):
                 self.browser.input_text('//h4[text()="Remove Labels"]/../../div/div/ul/li/input', label_remove.lower())
                 self.wait_element(f'//div[text()="{label_remove}" and @role="option"]')
             self.browser.click_element_when_visible(f'//div[text()="{label_remove}" and @role="option"]')
@@ -224,7 +252,11 @@ class CentralReachCore(SitesCore):
         self.browser.wait_until_element_is_not_visible('//h2[text()="Bulk Apply Labels"]')
 
     def change_billing(self, column_name: str, billing: str):
-        self.browser.click_element_when_visible('//th[contains(.,"' + column_name + '")]/div/a[contains(@data-bind, "{title: \'Search for different provider\'}")]')
+        self.browser.click_element_when_visible(
+            '//th[contains(.,"'
+            + column_name
+            + '")]/div/a[contains(@data-bind, "{title: \'Search for different provider\'}")]'
+        )
 
         self.wait_element('//th[contains(.,"{column_name}")]/div/div/input')
         self.browser.input_text_when_element_is_visible(f'//th[contains(.,"{column_name}")]/div/div/input', billing)
@@ -245,16 +277,16 @@ class CentralReachCore(SitesCore):
             self.browser.unselect_checkbox(f'//tr[@id="billing-grid-row-{timesheet_id}"]/td/input')
 
     def clear_location(self):
-        self.click_button_by_text('Location', 'Clear location')
-        self.sync_to_all_claims('Location')
+        self.click_button_by_text("Location", "Clear location")
+        self.sync_to_all_claims("Location")
 
     def clear_provider_supplier(self):
-        self.click_button_by_text('Provider Supplier', 'Clear provider supplier')
-        self.sync_to_all_claims('Provider Supplier')
+        self.click_button_by_text("Provider Supplier", "Clear provider supplier")
+        self.sync_to_all_claims("Provider Supplier")
 
     def clear_referrer(self):
-        self.click_button_by_text('Referrer', 'Clear referrer')
-        self.sync_to_all_claims('Referrer')
+        self.click_button_by_text("Referrer", "Clear referrer")
+        self.sync_to_all_claims("Referrer")
 
     def click_button_by_text(self, column_name: str, button_text: str):
         self.wait_element(f'//th[contains(.,"{column_name}")]/div/div/a/i')
@@ -279,5 +311,5 @@ class CentralReachCore(SitesCore):
         all_billings = self.browser.find_elements('//a[contains(@data-bind, "billingName")]')
         for billing in all_billings:
             if valid_billing.lower() not in str(billing.text).lower():
-                self.change_billing('Billing', full_billing_name)
+                self.change_billing("Billing", full_billing_name)
                 break
