@@ -13,12 +13,13 @@ class QuickbooksCore(SitesCore):
     """
     Quickbooks object. Please Inheritance it.
     """
+
     def get_otp_code(self) -> str:
         """
         Please, modify this function in your code
         :return:
         """
-        return ''
+        return ""
 
     def send_message_service_type_not_found(self, manager: str, customer_or_service: str) -> None:
         pass
@@ -57,24 +58,20 @@ class QuickbooksCore(SitesCore):
                     self.browser.click_element_when_visible('//button[@id="ius-identifier-first-submit-btn"]')
                     self.wait_element('//input[@id="ius-sign-in-mfa-password-collection-current-password"]')
                     self.browser.input_text(
-                        '//input[@id="ius-sign-in-mfa-password-collection-current-password"]',
-                        self.password
+                        '//input[@id="ius-sign-in-mfa-password-collection-current-password"]', self.password
                     )
                     self.browser.click_element_when_visible(
                         '//input[@id="ius-sign-in-mfa-password-collection-continue-btn"]'
                     )
 
-                self.wait_element('//div[text()="Let\'s make sure you\'re you"]', timeout=10, is_need_screenshot=False)
-                if self.does_element_displayed('//div[text()="Let\'s make sure you\'re you"]'):
+                self.wait_element("//div[text()=\"Let's make sure you're you\"]", timeout=10, is_need_screenshot=False)
+                if self.does_element_displayed("//div[text()=\"Let's make sure you're you\"]"):
                     self.browser.click_element_when_visible('//span[@id="ius-sublabel-mfa-email-otp"]')
                     if self.does_element_displayed('//input[@id="ius-mfa-options-submit-btn"]'):
                         self.browser.click_element_when_visible('//input[@id="ius-mfa-options-submit-btn"]')
 
                     self.wait_element('//input[@id="ius-mfa-confirm-code"]')
-                    self.browser.input_text(
-                        '//input[@id="ius-mfa-confirm-code"]',
-                        self.get_otp_code()
-                    )
+                    self.browser.input_text('//input[@id="ius-mfa-confirm-code"]', self.get_otp_code())
                     self.browser.click_element_when_visible('//input[@id="ius-mfa-otp-submit-btn"]')
                 self.wait_element('//*[@data-id="navigation-container"]')
                 if self.does_element_displayed('//*[@data-id="navigation-container"]'):
@@ -82,12 +79,10 @@ class QuickbooksCore(SitesCore):
                     self.is_site_available = True
                     return True
             except Exception as ex:
-                logging.error(f'Login failed. Attempt {i}', 'ERROR')
+                logging.error(f"Login failed. Attempt {i}", "ERROR")
                 logging.error(str(ex))
                 traceback.print_exc()
-                self.browser.capture_page_screenshot(
-                    os.path.join(self.output_folder, f'Login_failed_Attempt_{i}.png')
-                )
+                self.browser.capture_page_screenshot(os.path.join(self.output_folder, f"Login_failed_Attempt_{i}.png"))
                 self.browser.close_browser()
         return False
 
@@ -126,12 +121,14 @@ class QuickbooksCore(SitesCore):
             for element in elements:
                 try:
                     if element.is_displayed():
-                        logging.warning('A pop-up appeared and the bot closed it. Please validate the screenshot of the pop-up in the artifacts.')
+                        logging.warning(
+                            "A pop-up appeared and the bot closed it. Please validate the screenshot in the artifacts."
+                        )
                         self.browser.capture_page_screenshot(
                             os.path.join(self.output_folder, f'Pop_up_{datetime.now().strftime("%H_%M_%S")}.png')
                         )
                         element.click()
-                        self.browser.wait_until_element_is_not_visible(f'({xpath})[{elements.index(element) + 1}]')
+                        self.browser.wait_until_element_is_not_visible(f"({xpath})[{elements.index(element) + 1}]")
                 except (AssertionError, SeleniumLibraryException, StaleElementReferenceException):
                     sleep(1)
 
@@ -142,50 +139,45 @@ class QuickbooksCore(SitesCore):
         :param client_name: Client name
         :return: None
         """
-        self.click_bunch_of_elements([
-            '//span[text()="GO TO QUICKBOOKS"]',
-            f'//span[text()="{client_name}"]'
-        ])
+        self.click_bunch_of_elements(['//span[text()="GO TO QUICKBOOKS"]', f'//span[text()="{client_name}"]'])
         self.wait_element(f'//div[contains(@class, "companyName") and text()="{client_name}"]')
 
     def open_add_invoice_page(self) -> None:
         """
         Open page 'Add invoice'
         """
-        self.browser.go_to(f'{self.base_url}/app/homepage')
+        self.browser.go_to(f"{self.base_url}/app/homepage")
 
-        self.click_bunch_of_elements([
-            '//button[@data-id="global_create_button"]',
-            '//a[@data-id="invoice"]'
-        ])
+        self.click_bunch_of_elements(['//button[@data-id="global_create_button"]', '//a[@data-id="invoice"]'])
 
     def open_add_estimate_page(self) -> None:
         """
         Open page 'Add estimate'
         """
-        self.browser.go_to(f'{self.base_url}/app/homepage')
+        self.browser.go_to(f"{self.base_url}/app/homepage")
 
-        self.click_bunch_of_elements([
-            '//button[@data-id="global_create_button"]',
-            '//a[@data-id="estimate"]'
-        ])
+        self.click_bunch_of_elements(['//button[@data-id="global_create_button"]', '//a[@data-id="estimate"]'])
 
     def open_invoices_page(self) -> None:
         """
         Check paid page
         """
-        self.browser.go_to(f'{self.base_url}/app/homepage')
-        self.click_bunch_of_elements([
-            '//span[text()="Sales"]/..',
-            '//a[text()="Invoices"]',
-            '//th[@data-column-id="date"]',
-            '//div[contains(@class, "TextFieldWrapper")]//input[not(@data-automation-id)]',
-            '//li[text()="Paid"]',
-            '//div[contains(@class, "TextFieldWrapper")]//input[@data-automation-id="date-dropdown"]',
-            '//li[text()="Last 3 months"]',
-        ])
+        self.browser.go_to(f"{self.base_url}/app/homepage")
+        self.click_bunch_of_elements(
+            [
+                '//span[text()="Sales"]/..',
+                '//a[text()="Invoices"]',
+                '//th[@data-column-id="date"]',
+                '//div[contains(@class, "TextFieldWrapper")]//input[not(@data-automation-id)]',
+                '//li[text()="Paid"]',
+                '//div[contains(@class, "TextFieldWrapper")]//input[@data-automation-id="date-dropdown"]',
+                '//li[text()="Last 3 months"]',
+            ]
+        )
         self.wait_element('//th[@data-column-id="date" and contains(@class, "sorted-desc")]', 5, False)
-        if not self.browser.does_page_contain_element('//th[@data-column-id="date" and contains(@class, "sorted-desc")]'):
+        if not self.browser.does_page_contain_element(
+            '//th[@data-column-id="date" and contains(@class, "sorted-desc")]'
+        ):
             self.browser.click_element_when_visible('//th[@data-column-id="date"]')
         self.wait_element('//div[@data-sale-status="PAID"]/../..', 15, False)
 
@@ -208,11 +200,11 @@ class QuickbooksCore(SitesCore):
         customer: str = first_row.customer
 
         self.wait_element('//input[@aria-label="Select a customer"]')
-        self.browser.input_text('//input[@aria-label="Select a customer"]', customer.replace('\\', '\\\\'))
+        self.browser.input_text('//input[@aria-label="Select a customer"]', customer.replace("\\", "\\\\"))
 
         self.wait_element(f'//span[text()="Add new"]/../span[text()="{customer}"]', 10, False)
 
-        xpath_customers: str = f'//div[@aria-label="Select a customer"]/div[not(@aria-label)]//span[@class="mainLabel"]'
+        xpath_customers: str = '//div[@aria-label="Select a customer"]/div[not(@aria-label)]//span[@class="mainLabel"]'
         customers: list = self.browser.find_elements(xpath_customers)
         if len(customers) > 1:
             for i in range(3):
@@ -237,13 +229,10 @@ class QuickbooksCore(SitesCore):
                     break
         if not selected:
             self.browser.capture_page_screenshot(
-                os.path.join(
-                    self.output_folder,
-                    f'No_customer_{datetime.now().strftime("%H_%M_%S")}.png'
-                )
+                os.path.join(self.output_folder, f'No_customer_{datetime.now().strftime("%H_%M_%S")}.png')
             )
             self.send_message_service_type_not_found(first_row.manager, customer)
-            return False, '', ''
+            return False, "", ""
 
         index: int = 1
         total_rate: float = 0.0
@@ -261,17 +250,16 @@ class QuickbooksCore(SitesCore):
             self.wait_element(
                 f'//div[@class="name"]/span[text()="{service}" and @class="dijitComboBoxHighlightMatch"]', 5, False
             )
-            if not self.does_element_displayed(f'//div[@class="name"]/span[text()="{service}" and @class="dijitComboBoxHighlightMatch"]'):
+            if not self.does_element_displayed(
+                f'//div[@class="name"]/span[text()="{service}" and @class="dijitComboBoxHighlightMatch"]'
+            ):
                 self.wait_element(f'//div/span/b[text()="{service}"]')
                 if not self.does_element_displayed(f'//div/span/b[text()="{service}"]'):
                     self.browser.capture_page_screenshot(
-                        os.path.join(
-                            self.output_folder,
-                            f'No_service_{datetime.now().strftime("%H_%M_%S")}.png'
-                        )
+                        os.path.join(self.output_folder, f'No_service_{datetime.now().strftime("%H_%M_%S")}.png')
                     )
                     self.send_message_service_type_not_found(first_row.manager, service)
-                    return False, '', ''
+                    return False, "", ""
                 else:
                     self.browser.click_element_when_visible(f'//div/span/b[text()="{service}"]')
             else:
@@ -286,24 +274,25 @@ class QuickbooksCore(SitesCore):
         total_rate = round(total_rate, 2)
         processing_fee: bool = first_row.processing_fee
         if processing_fee:
-            processing_fee_name: str = '3% QuickBooks Processing Fee'
+            processing_fee_name: str = "3% QuickBooks Processing Fee"
             self.browser.click_element_when_visible(f'//td[text()="{index}"]')
             self.wait_element('//input[contains(@id, "ItemComboBox") or @aria-label="ProductService"]')
             self.browser.input_text(
-                '//input[contains(@id, "ItemComboBox") or @aria-label="ProductService"]',
-                processing_fee_name
+                '//input[contains(@id, "ItemComboBox") or @aria-label="ProductService"]', processing_fee_name
             )
 
             self.wait_element(f'//div/span/b[text()="{processing_fee_name}"]')
             self.browser.click_element_when_visible(f'//div/span/b[text()="{processing_fee_name}"]')
-            sleep(.5)
+            sleep(0.5)
 
             self.wait_element('//input[@data-automation-id="input-rateField"]')
             self.browser.input_text(
-                '//input[@data-automation-id="input-rateField"]', str('%.2f' % (total_rate / 0.97 - total_rate))
+                '//input[@data-automation-id="input-rateField"]', str("%.2f" % (total_rate / 0.97 - total_rate))
             )
 
-        self.wait_element('//input[@data-automation-id="input-dropdown-terms-sales"]/..//div[contains(@class, "dropDownImage")]')
+        self.wait_element(
+            '//input[@data-automation-id="input-dropdown-terms-sales"]/..//div[contains(@class, "dropDownImage")]'
+        )
         self.browser.click_element_when_visible(
             '//input[@data-automation-id="input-dropdown-terms-sales"]/..//div[contains(@class, "dropDownImage")]'
         )
@@ -311,29 +300,29 @@ class QuickbooksCore(SitesCore):
         self.browser.click_element_when_visible('//div[text()="Due on receipt"]')
 
         invoice_date: str = self.browser.get_value('//input[@data-automation-id="input-creation-date-sales"]')
-        invoice_number: str = '1234'
+        invoice_number: str = "1234"
         if is_prod:
             self.browser.click_element_when_visible('//button[text()="Save and send"]')
             self.wait_element('//button[text()="Send and close"]')
             invoice_number = self.browser.get_text('//div[@data-qbo-bind="text: referenceNumber"]')
             self.browser.click_element_when_visible('//button[text()="Send and close"]')
         else:
-            print('Dev test. The invoice was not saved')
+            print("Dev test. The invoice was not saved")
             self.browser.capture_page_screenshot(
                 os.path.join(
-                    self.output_folder,
-                    f'Test_run-customer_{customer}-{datetime.now().strftime("%H_%M_%S")}.png'
+                    self.output_folder, f'Test_run-customer_{customer}-{datetime.now().strftime("%H_%M_%S")}.png'
                 )
             )
             self.browser.click_element_when_visible('//i[@aria-label="Close"]')
             self.wait_element('//button[text()="Yes"]', 5)
             if self.does_element_displayed('//button[text()="Yes"]'):
                 self.browser.click_element_when_visible('//button[text()="Yes"]')
-        self.send_message_invoice_added(first_row.manager,
-                                        first_row.customer,
-                                        invoice_number,
-                                        total_rate,
-                                        )
+        self.send_message_invoice_added(
+            first_row.manager,
+            first_row.customer,
+            invoice_number,
+            total_rate,
+        )
 
         return True, invoice_date, invoice_number
 
@@ -341,11 +330,8 @@ class QuickbooksCore(SitesCore):
         """
         Open Customers page
         """
-        self.browser.go_to(f'{self.base_url}/app/homepage')
-        self.click_bunch_of_elements([
-            '//span[text()="Sales"]/..',
-            '//a[text()="Customers"]'
-        ])
+        self.browser.go_to(f"{self.base_url}/app/homepage")
+        self.click_bunch_of_elements(['//span[text()="Sales"]/..', '//a[text()="Customers"]'])
         self.wait_element('//li[contains(@class, "active")]/a[text()="Customers"]', 5, False)
 
     def add_new_customer(self, customer_name: str, first_name: str, last_name: str, email: str) -> bool:
@@ -365,14 +351,14 @@ class QuickbooksCore(SitesCore):
         if self.does_element_displayed(f'//p[@data-qbo-bind="text: companyName" and text()="{customer_name}"]'):
             return True
         else:
-            error: str = ''
+            error: str = ""
             for alert in self.browser.find_elements('//div[@class="alert-content"]'):
                 if alert.is_displayed():
                     error: str = alert.text
                     print(error)
                     break
             self.browser.click_element_when_visible('//button[@data-automation-id="customerCancelBtn"]')
-            if 'Please use a different name' in error:
+            if "Please use a different name" in error:
                 return True
         return False
 
@@ -395,11 +381,11 @@ class QuickbooksCore(SitesCore):
         customer: str = first_row.customer
 
         self.wait_element('//input[@aria-label="Choose a customer"]')
-        self.browser.input_text('//input[@aria-label="Choose a customer"]', customer.replace('\\', '\\\\'))
+        self.browser.input_text('//input[@aria-label="Choose a customer"]', customer.replace("\\", "\\\\"))
 
         self.wait_element(f'//span[text()="Add new"]/../span[text()="{customer}"]', 10, False)
 
-        xpath_customers: str = f'//div[@aria-label="Choose a customer"]/div[not(@aria-label)]//span[@class="mainLabel"]'
+        xpath_customers: str = '//div[@aria-label="Choose a customer"]/div[not(@aria-label)]//span[@class="mainLabel"]'
         customers: list = self.browser.find_elements(xpath_customers)
         if len(customers) > 1:
             for i in range(3):
@@ -424,13 +410,10 @@ class QuickbooksCore(SitesCore):
                     break
         if not selected:
             self.browser.capture_page_screenshot(
-                os.path.join(
-                    self.output_folder,
-                    f'No_customer_{datetime.now().strftime("%H_%M_%S")}.png'
-                )
+                os.path.join(self.output_folder, f'No_customer_{datetime.now().strftime("%H_%M_%S")}.png')
             )
             self.send_message_service_type_not_found(first_row.manager, customer)
-            return False, '', ''
+            return False, "", ""
 
         index: int = 1
         total_rate: float = 0.0
@@ -448,17 +431,16 @@ class QuickbooksCore(SitesCore):
             self.wait_element(
                 f'//div[@class="name"]/span[text()="{service}" and @class="dijitComboBoxHighlightMatch"]', 5, False
             )
-            if not self.does_element_displayed(f'//div[@class="name"]/span[text()="{service}" and @class="dijitComboBoxHighlightMatch"]'):
+            if not self.does_element_displayed(
+                f'//div[@class="name"]/span[text()="{service}" and @class="dijitComboBoxHighlightMatch"]'
+            ):
                 self.wait_element(f'//div/span/b[text()="{service}"]')
                 if not self.does_element_displayed(f'//div/span/b[text()="{service}"]'):
                     self.browser.capture_page_screenshot(
-                        os.path.join(
-                            self.output_folder,
-                            f'No_service_{datetime.now().strftime("%H_%M_%S")}.png'
-                        )
+                        os.path.join(self.output_folder, f'No_service_{datetime.now().strftime("%H_%M_%S")}.png')
                     )
                     self.send_message_service_type_not_found(first_row.manager, service)
-                    return False, '', ''
+                    return False, "", ""
                 else:
                     self.browser.click_element_when_visible(f'//div/span/b[text()="{service}"]')
             else:
@@ -474,50 +456,49 @@ class QuickbooksCore(SitesCore):
         total_rate = round(total_rate, 2)
         processing_fee: bool = first_row.processing_fee
         if processing_fee:
-            processing_fee_name: str = '3% QuickBooks Processing Fee'
+            processing_fee_name: str = "3% QuickBooks Processing Fee"
             self.browser.click_element_when_visible(f'//td[text()="{index}"]')
             self.wait_element('//input[contains(@id, "ItemComboBox") or @aria-label="ProductService"]')
             self.browser.input_text(
-                '//input[contains(@id, "ItemComboBox") or @aria-label="ProductService"]',
-                processing_fee_name
+                '//input[contains(@id, "ItemComboBox") or @aria-label="ProductService"]', processing_fee_name
             )
 
             self.wait_element(f'//div/span/b[text()="{processing_fee_name}"]')
             self.browser.click_element_when_visible(f'//div/span/b[text()="{processing_fee_name}"]')
 
             self.browser.input_text(
-                '//input[@data-automation-id="input-rateField"]', str('%.2f' % (total_rate / 0.97 - total_rate))
+                '//input[@data-automation-id="input-rateField"]', str("%.2f" % (total_rate / 0.97 - total_rate))
             )
             self.browser.input_text(
-                '//input[@data-automation-id="amountField"]', str('%.2f' % (total_rate / 0.97 - total_rate))
+                '//input[@data-automation-id="amountField"]', str("%.2f" % (total_rate / 0.97 - total_rate))
             )
 
         self.wait_element('//input[@data-automation-id="input-creation-date-sales"]')
         self.browser.click_element_when_visible('//input[@data-automation-id="input-creation-date-sales"]')
 
         estimate_date: str = self.browser.get_value('//input[@data-automation-id="input-creation-date-sales"]')
-        estimate_number: str = '1234'
+        estimate_number: str = "1234"
         if is_prod:
             self.browser.click_element_when_visible('//button[text()="Save and send"]')
             self.wait_element('//button[text()="Send and close"]')
             estimate_number = self.browser.get_text('//div[@data-qbo-bind="text: referenceNumber"]')
             self.browser.click_element_when_visible('//button[text()="Send and close"]')
         else:
-            print('Dev test. The invoice was not saved')
+            print("Dev test. The invoice was not saved")
             self.browser.capture_page_screenshot(
                 os.path.join(
-                    self.output_folder,
-                    f'Test_run-customer_{customer}-{datetime.now().strftime("%H_%M_%S")}.png'
+                    self.output_folder, f'Test_run-customer_{customer}-{datetime.now().strftime("%H_%M_%S")}.png'
                 )
             )
             self.browser.click_element_when_visible('//i[@aria-label="Close"]')
             self.wait_element('//button[text()="Yes"]', 5)
             if self.does_element_displayed('//button[text()="Yes"]'):
                 self.browser.click_element_when_visible('//button[text()="Yes"]')
-        self.send_message_estimate_added(first_row.manager,
-                                         first_row.customer,
-                                         estimate_number,
-                                         total_rate,
-                                         )
+        self.send_message_estimate_added(
+            first_row.manager,
+            first_row.customer,
+            estimate_number,
+            total_rate,
+        )
 
         return True, estimate_date, estimate_number
